use crate::util::error::*;
use crate::util::serverfn_client::Client;
use leptos::prelude::*;

#[server(endpoint = "health", client = Client)]
pub async fn health() -> BackendResult<String> {
    use crate::util::backend_state::BackendState;
    use diesel::connection::SimpleConnection;
    use tower_sessions_redis_store::fred::interfaces::ClientLike;

    let backend_state = BackendState::get().await?;

    backend_state
        .get_db_conn()?
        .batch_execute("SELECT 1")
        .context("Failed to execute database health check query")?;

    backend_state
        .get_redis_conn()
        .ping::<()>(None)
        .await
        .map_err(|e| BackendError::InternalError(format!("{e}")))
        .context("Failed to execute Redis health check ping")?;

    Ok("ok".to_string())
}
