use libretunes_macro::db_type;
use serde::{Deserialize, Serialize};

/// Model for an artist
#[db_type(crate::schema::artists)]
#[derive(Serialize, Deserialize, Clone, Debug)]
pub struct Artist {
    /// A unique id for the artist
    #[omit_new]
    pub id: i32,
    /// The artist's name
    pub name: String,
}

impl Artist {
    /// Display a list of artists as a string.
    ///
    /// For one artist, displays [artist1]. For two artists, displays [artist1] & [artist2].
    /// For three or more artists, displays [artist1], [artist2], & [artist3].
    pub fn display_list(artists: &[Artist]) -> String {
        let mut artist_list = String::new();

        for (i, artist) in artists.iter().enumerate() {
            if i == 0 {
                artist_list.push_str(&artist.name);
            } else if i == artists.len() - 1 {
                artist_list.push_str(&format!(" & {}", artist.name));
            } else {
                artist_list.push_str(&format!(", {}", artist.name));
            }
        }

        artist_list
    }
}
