use crate::api::users::UserCredentials;
use axum_login::{AuthUser, AuthnBackend, UserId};

use crate::models::backend::User;
use crate::util::backend_state::BackendState;
use crate::util::error::*;

use async_trait::async_trait;

impl AuthUser for User {
    type Id = i32;

    fn id(&self) -> Self::Id {
        self.id
    }

    fn session_auth_hash(&self) -> &[u8] {
        self.password.as_ref().unwrap().as_bytes()
    }
}

#[derive(Clone)]
pub struct AuthBackend {
    /// The backend state is needed for the database connection
    /// `extract`ing the backend state is not possible in this context
    pub backend_state: BackendState,
}

#[async_trait]
impl AuthnBackend for AuthBackend {
    type User = User;
    type Credentials = UserCredentials;
    type Error = BackendError;

    async fn authenticate(
        &self,
        creds: Self::Credentials,
    ) -> Result<Option<Self::User>, Self::Error> {
        let mut db_conn = self.backend_state.get_db_conn()?;

        crate::api::users::validate_user(creds, &mut db_conn)
            .await
            .context("Error validating user credentials")
    }

    async fn get_user(&self, user_id: &UserId<Self>) -> Result<Option<Self::User>, Self::Error> {
        let mut db_conn = self.backend_state.get_db_conn()?;

        crate::api::users::find_user_by_id(*user_id, &mut db_conn)
            .await
            .context("Error finding user by ID")
    }
}
